/** Header file generated with fdesign on Thu Mar  2 14:24:57 2000.**/

#ifndef FD_bla_h_
#define FD_bla_h_

/** Callbacks, globals and object handlers **/


/**** Forms and Objects ****/
typedef struct {
	FL_FORM *bla;
	void *vdata;
	char *cdata;
	long  ldata;
	FL_OBJECT *canvas;
} FD_bla;

extern FD_bla * create_form_bla(void);

#endif /* FD_bla_h_ */
