/* Form definition file generated with fdesign. */

#include "forms.h"
#include <stdlib.h>
#include "bla.h"

FD_bla *create_form_bla(void)
{
  FL_OBJECT *obj;
  FD_bla *fdui = (FD_bla *) fl_calloc(1, sizeof(*fdui));

  fdui->bla = fl_bgn_form(FL_NO_BOX, 320, 250);
  obj = fl_add_box(FL_UP_BOX,0,0,320,250,"");
  fdui->canvas = obj = fl_add_canvas(FL_NORMAL_CANVAS,30,30,240,140,"");
  obj = fl_add_button(FL_NORMAL_BUTTON,40,190,210,40,"button");
  fl_end_form();

  fdui->bla->fdui = fdui;

  return fdui;
}
/*---------------------------------------*/

