#include "forms.h"
#include "bla.h"

int main(int argc, char *argv[])
{
   FD_bla *fd_bla;

   fl_initialize(&argc, argv, 0, 0, 0);
   fd_bla = create_form_bla();

   /* fill-in form initialization code */

   /* show the first form */
   fl_show_form(fd_bla->bla,FL_PLACE_CENTERFREE,FL_FULLBORDER,"bla");
   fl_do_forms();
   fl_hide_object(fd_bla->canvas);
   fl_hide_form(fd_bla->bla);

   fl_show_form(fd_bla->bla,FL_PLACE_CENTERFREE,FL_FULLBORDER,"bla");
   fl_show_object(fd_bla->canvas);
   fl_do_forms();
   return 0;
}
